import {
  select,
  csv,
  scaleLinear,
  scaleTime,
  axisLeft,
  extent,
  axisBottom,
  format
} from 'd3';

 
const svg = select('svg');

const width = +svg.attr('width');
const height = +svg.attr('height');


const render = data => {
	const xAxisLabelText = 'Time';
	const yAxisLabelText = 'Temperature';
  const titleText = `Temperature in San Francisco`;

  const radius = 5;
  const xValue = d => d.timestamp;
  const yValue = d => d.temperature;
  const margin = { top: 60, right: 40, bottom: 100, left: 180 };
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;
  
  
  //Crio as escalas (Cálculo para dimensionar 
  //os elementos no grafo)
  const xScale = scaleTime()
    .domain(extent(data, xValue))// você só usa [] para mais de uma argumento
    .range([0, innerWidth])
  	.nice();
  
  const yScale = scaleLinear()
    .domain(extent(data, yValue))
    .range([innerHeight, 0])
  	.nice();
  
  //crio o grupo g
  const g = svg.append('g')
    .attr('transform', `translate(${margin.left},${margin.top})`);
  
  
  //Crio os eixos (axis) aqui, 
  //usando as funções que definem sua posição
  const xAxis = axisBottom(xScale).tickSize(-innerHeight);
  const yAxis = axisLeft(yScale).tickSize(-innerWidth);
  
  //Ajustando os Axis
  yAxis.tickPadding(10);
  xAxis.tickPadding(15);
 	
  
  //Crio os grupos que envolve os Axis 
  //para ipodermos inserir outros elementos
  const yAxisG = g.append('g').call(yAxis);   
  const xAxisG = g.append('g').call(xAxis);
  
  
  //Alteramos o eixo y, envolvendo legendas
  yAxisG.selectAll('.domain').remove();
  yAxisG.append('text')
      .attr('class', 'axis-label')
      .attr('y', -95)
      .attr('x', -innerHeight / 2)
  		.attr('transform', 'rotate(-90)')
  		.attr('text-anchor', 'middle')
      .text(yAxisLabelText);
  
  
	//Alteramos o eixo x, envolvendo legendas
  xAxisG.attr('transform', `translate(0,${innerHeight})`);
  xAxisG.select('.domain').remove(); 
  xAxisG.append('text')
      .attr('class', 'axis-label')
      .attr('y', 85)
      .attr('x', innerWidth / 2)
      .text(xAxisLabelText);
  
  
  //cria os elementos no grafo
  g.selectAll('circle').data(data)
    .enter().append('circle')
      .attr('cy', d => yScale(yValue(d)))
      .attr('cx', d => xScale(xValue(d)))
      .attr('r',  radius);
  
  
  //Cria o título
  g.append('text')
      .attr('class', 'title')
      .attr('y', -10)
      .text(titleText);
};


//requisição do JSON
csv('https://vizhub.com/curran/datasets/temperature-in-san-francisco.csv')
  .then(data => {
		data.forEach(d => {
  	d.timestamp = new Date(d.timestamp);
    d.temperature = +d.temperature;
    
  });
  
  console.log(data);
  render(